@@ -1,6 +1,8 @@
 from __future__ import absolute_import
 
-from sentry_sdk._types import MYPY
+import re
+
+from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.hub import Hub
 from sentry_sdk.integrations import Integration, DidNotEnable
 from sentry_sdk.tracing_utils import record_sql_queries
@@ -12,7 +14,7 @@ try:
 except ImportError:
     raise DidNotEnable("SQLAlchemy not installed.")
 
-if MYPY:
+if TYPE_CHECKING:
     from typing import Any
     from typing import ContextManager
     from typing import Optional
@@ -28,7 +30,9 @@ class SqlalchemyIntegration(Integration):
         # type: () -> None
 
         try:
-            version = tuple(map(int, SQLALCHEMY_VERSION.split("b")[0].split(".")))
+            version = tuple(
+                map(int, re.split("b|rc", SQLALCHEMY_VERSION)[0].split("."))
+            )
         except (TypeError, ValueError):
             raise DidNotEnable(
                 "Unparsable SQLAlchemy version: {}".format(SQLALCHEMY_VERSION)
@@ -70,7 +74,7 @@ def _after_cursor_execute(conn, cursor, statement, parameters, context, *args):
     # type: (Any, Any, Any, Any, Any, *Any) -> None
     ctx_mgr = getattr(
         context, "_sentry_sql_span_manager", None
-    )  # type: ContextManager[Any]
+    )  # type: Optional[ContextManager[Any]]
 
     if ctx_mgr is not None:
         context._sentry_sql_span_manager = None
@@ -93,7 +97,7 @@ def _handle_error(context, *args):
     # handler is going to be fatal.
     ctx_mgr = getattr(
         execution_context, "_sentry_sql_span_manager", None
-    )  # type: ContextManager[Any]
+    )  # type: Optional[ContextManager[Any]]
 
     if ctx_mgr is not None:
         execution_context._sentry_sql_span_manager = None
